@@ -129,7 +129,6 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
                     'timeout': self.__conn_timeout, 'connect_timeout': self.__conn_timeout,
                     'options': '-c statement_timeout=%s' % self.__query_timeout}
             )
-            engine.connect()
 
             @event.listens_for(engine, "engine_connect")
             def ping_connection(connection, branch):
@@ -140,12 +139,18 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
                     connection.scalar(select([1]))
                 except exc.DBAPIError as err:
                     if err.connection_invalidated:
-                        connection.scalar(select([1]))
+                        try:
+                            connection.scalar(select([1]))
+                        except exc.DBAPIError as err:
+                            raise ValueError('Unable to connect %s' % err)
+                    else:
+                        raise ValueError('Unable to connect %s' % err)
                 else:
-                    close_engine(engine)
-
                     if test_conn:
+                        close_engine(engine)
                         return False
+
+            engine.connect()
         else:
             engine = None
 
