@@ -28,6 +28,27 @@ class XML(object):
         self.xml_file = xml_file
         self.read_handlers = list()
 
+    def check(self, xml_file=None):
+        """
+        Reads XML to see if has illegal characters
+
+        :return: True/False
+        """
+
+        if xml_file is None:
+            xml_file = self.xml_file
+
+        if not os.path.exists(xml_file):
+            raise Exception("'xml_file' %r is not a valid filepath" % xml_file)
+
+        try:
+            tree = ET.parse(xml_file)
+            return True
+        except:
+            pass
+
+        return False
+
     def read(self, xmlns_rs, dict_var=None):
         """
         Reads XML files and store in a dict or pandas DataFrame
@@ -77,16 +98,14 @@ class XML(object):
         if not isinstance(dataframe, DataFrame):
             raise ValueError("'dataframe' %r is not an instance of DataFrame from pandas" % dataframe)
 
-        xml_file = self.xml_file
-
-        while os.path.exists(xml_file):
+        while os.path.exists(self.xml_file):
             uid = get_random_string(length=16,
                                     allowed_chars=u'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789')
             date = datetime.datetime.now()
-            xml_file = os.path.join(os.path.dirname(xml_file),
+            self.xml_file = os.path.join(os.path.dirname(xml_file),
                                     '%s-%s-%s_%s.xml' % (date.year, date.month, date.day, uid))
 
-        with Open(xml_file, 'w') as xmlfile:
+        with Open(self.xml_file, 'w') as xmlfile:
             xmlfile.write('<?xml version="1.0" encoding="UTF-8"?>\n')
             xmlfile.write('<records>\n')
             xmlfile.write(
